Module split

Module split 

split Frames into pieces

at its most basic level, a Frame is a character grid with some associated input. that’s not a very useful abstraction to work with, though – especially not for a ui library.

so instead, you start with a whole frame, then split it into sub-frames, then sub-sub-frames, and once you have your layout, you populate each sub-*-frame with a Component.

Traits

Splitter
a strategy for splitting a Frame into sub-frames